@@ -1,8 +1,8 @@
 /* r2ghidra- LGPL - Copyright 2019-2023 - thestr4ng3r, pancake */
 
-#include "R2Scope.h"
 #include "R2Architecture.h"
 #include "R2TypeFactory.h"
+#include "R2Scope.h"
 
 #include <funcdata.hh>
 
@@ -151,10 +151,15 @@ FunctionSymbol *R2Scope::registerFunction(RAnalFunction *fcn) const {
 
 	auto symbollistElement = child(scopeElement, "symbollist");
 
-	ProtoModel *proto = fcn->cc ? arch->protoModelFromR2CC(fcn->cc) : nullptr;
+#if R2_VERSION_NUMBER >= 50909
+#define CALLCONV(x) (x)->callconv
+#else
+#define CALLCONV(x) (x)->cc
+#endif
+	ProtoModel *proto = CALLCONV(fcn) ? arch->protoModelFromR2CC(CALLCONV(fcn)) : nullptr;
 	if (!proto) {
-		if (fcn->cc) {
-			arch->addWarning ("Matching calling convention " + to_string(fcn->cc) + " of function " + to_string(fcn_name) + " failed, args may be inaccurate.");
+		if (CALLCONV(fcn)) {
+			arch->addWarning ("Matching calling convention " + to_string(CALLCONV(fcn)) + " of function " + to_string(fcn_name) + " failed, args may be inaccurate.");
 		} else {
 			arch->addWarning ("Function " + to_string(fcn_name) + " has no calling convention set, args may be inaccurate.");
 		}
