@@ -1,7 +1,7 @@
 /* r2ghidra - LGPL - Copyright 2020-2023 - FXTi, pancake */
 
-#include "SleighAsm.h"
 #include "ArchMap.h"
+#include "SleighAsm.h"
 
 // define it here because sleighc needs to compile without anal_ghidra.cpp
 extern "C" {
@@ -240,8 +240,9 @@ void SleighAsm::buildSpecfile(DocumentStorage &store)
 		serr << "\n " << err.explain;
 		throw SleighError (serr.str ());
 	}
+	istringstream s("<sleigh>" + slafile + "</sleigh>");
 	try {
-		Document *doc = store.openDocument (slafile);
+		Document *doc = store.parseDocument (s);
 		store.registerTag (doc->getRoot());
 	} catch (DecoderError &err) {
 		ostringstream serr;
@@ -405,7 +406,7 @@ RConfig *SleighAsm::getConfig(RAnal *a) {
 	return core->config;
 }
 
-std::string SleighAsm::getSleighHome(R_NULLABLE RConfig *cfg) {
+std::string SleighAsm::getSleighHome(RConfig * R_NULLABLE cfg) {
 	const char varname[] = "r2ghidra.sleighhome";
 	char *path = nullptr;
 
